Package: progeny
Title: Pathway RespOnsive GENes for activity inference from gene
        expression
Version: 1.33.0
Authors@R: c(
    person(given = "Michael",
           family = "Schubert",
           role = "aut"),
    person(given = "Alberto",
           family = "Valdeolivas",
           role = "ctb",
           email = "alvaldeolivas@gmail.com",
           comment = c(ORCID = "0000-0001-5482-9023")),
    person(given = "Christian H.",
           family = "Holland",
           role = "ctb",
           email = "cholland2408@gmail.com",
           comment = c(ORCID = "0000-0002-3060-5786")),
    person(given = "Igor",
           family = "Bulanov",
           role = "ctb"),
    person(given = "Aurélien",
           family = "Dugourd",
           role = c("cre","ctb"), 
           email = "aurelien.dugourd@bioquant.uni-heidelberg.de")
           )
Description: PROGENy is resource that leverages a large compendium of publicly available signaling perturbation experiments to yield a common core of pathway responsive genes for human and mouse. These, coupled with any statistical method, can be used to infer pathway activities from bulk or single-cell transcriptomics. 
URL: https://github.com/saezlab/progeny
BugReports: https://github.com/saezlab/progeny/issues
Depends: R (>= 3.6.0)
Imports: Biobase, stats, dplyr, tidyr, ggplot2, ggrepel, gridExtra,
        decoupleR, reshape2
biocViews: SystemsBiology, GeneExpression, FunctionalPrediction,
        GeneRegulation
License: Apache License (== 2.0) | file LICENSE
LazyData: true
LazyDataCompression: bzip2
Encoding: UTF-8
Suggests: airway, biomaRt, BiocFileCache, broom, Seurat,
        SingleCellExperiment, DESeq2, BiocStyle, knitr, readr, readxl,
        pheatmap, tibble, rmarkdown, testthat (>= 2.1.0)
VignetteBuilder: knitr
RoxygenNote: 7.1.2
git_url: https://git.bioconductor.org/packages/progeny
git_branch: devel
git_last_commit: 397f983
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 22:28:38 UTC; biocbuild
Author: Michael Schubert [aut],
  Alberto Valdeolivas [ctb] (ORCID:
    <https://orcid.org/0000-0001-5482-9023>),
  Christian H. Holland [ctb] (ORCID:
    <https://orcid.org/0000-0002-3060-5786>),
  Igor Bulanov [ctb],
  Aurélien Dugourd [cre, ctb]
Maintainer: Aurélien Dugourd <aurelien.dugourd@bioquant.uni-heidelberg.de>
