# Generated by roxygen2: do not edit by hand

S3method(progeny,ExpressionSet)
S3method(progeny,Seurat)
S3method(progeny,SingleCellExperiment)
S3method(progeny,default)
S3method(progeny,matrix)
export(getModel)
export(progeny)
export(progenyPerm)
export(progenyScatter)
export(saveProgenyPlots)
import(ggplot2)
import(ggrepel)
import(gridExtra)
importFrom(dplyr,group_by)
importFrom(dplyr,select)
importFrom(dplyr,top_n)
importFrom(dplyr,ungroup)
importFrom(reshape2,melt)
importFrom(stats,complete.cases)
importFrom(stats,ecdf)
importFrom(stats,sd)
importFrom(tidyr,"%>%")
importFrom(tidyr,spread)
