% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.r
\name{model_human_full}
\alias{model_human_full}
\title{The full human linear model underlying PROGENy}
\format{
The full human model contains 22479 genes, associated pathways,
weight and the p-value.         
\describe{
    \item{gene}{gene names in HGNC symbols}
    \item{pathway}{names of PROGENy pathways}
    \item{weight}{z-scores for a given gene}
    \item{p.value}{significance of gene in pathway}
}
}
\source{
\url{https://www.nature.com/articles/s41467-017-02391-6}
}
\description{
HGNC gene symbols in rows, pathways in columns. Pathway activity inference
works by matrix multiplication of gene expression with the model.
}
\examples{
get("model_human_full", envir = .GlobalEnv)
}
\keyword{datasets}
